Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(818)

Unified Diff: components/history/core/browser/history_service.h

Issue 1908443003: Set site engagement timestamps to privacy-respectful values when history is cleared. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@2704
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/history/core/browser/history_service.h
diff --git a/components/history/core/browser/history_service.h b/components/history/core/browser/history_service.h
index c830e25f1bcebf18ea827bb800d4c454ee078fb8..a27e4e0d6538c86e403df4cedb062a5f0ecaee15 100644
--- a/components/history/core/browser/history_service.h
+++ b/components/history/core/browser/history_service.h
@@ -152,9 +152,10 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
// KeyedService:
void Shutdown() override;
- // Callback for value asynchronously returned by GetCountsForOrigins().
- typedef base::Callback<void(const OriginCountMap&)>
- GetCountsForOriginsCallback;
+ // Callback for value asynchronously returned by
+ // GetCountsAndLastVisitForOrigins().
+ typedef base::Callback<void(const OriginCountAndLastVisitMap&)>
+ GetCountsAndLastVisitForOriginsCallback;
// Computes the |num_hosts| most-visited hostnames in the past 30 days and
// returns a list of those hosts paired with their visit counts. The following
@@ -171,9 +172,11 @@ class HistoryService : public syncer::SyncableService, public KeyedService {
virtual void TopHosts(size_t num_hosts,
const TopHostsCallback& callback) const;
- // Gets the counts of URLs that belong to |origins| in the history database.
- void GetCountsForOrigins(const std::set<GURL>& origins,
- const GetCountsForOriginsCallback& callback) const;
+ // Gets the counts and most recent visit date of URLs that belong to |origins|
+ // in the history database.
+ void GetCountsAndLastVisitForOrigins(
+ const std::set<GURL>& origins,
+ const GetCountsAndLastVisitForOriginsCallback& callback) const;
// Returns, for the given URL, a 0-based index into the list produced by
// TopHosts(), corresponding to that URL's host. If TopHosts() has not
« no previous file with comments | « components/history/core/browser/history_backend_unittest.cc ('k') | components/history/core/browser/history_service.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698